<?php 
if ( ! defined( 'ABSPATH' ) ) die( 'Direct access forbidden.' );

if( ! class_exists( 'Livekitchen_Theme_Master' ) ) :
class Livekitchen_Theme_Master {

    /**
     * Call all loading functions for the theme. They will be started right after theme setup.
     * 
     * @since v1.0
     */
    public function __construct() { 
        // Run after instalation setup.
        $this->theme_setup();

        // Register actions using add_actions() custom function.
        $this->add_actions();
    }

    /**
     * Initial theme setup
     * 
     * Loading scripts and stylesheets. Register custom elements
     * and functionality in the theme.
     * 
     * @uses get_template_directory_uri()
     * @uses add_theme_support()
     * @since v1.0
     */
    public function theme_setup() {
        // Set content width for custom media information
        global $content_width;
        if ( ! isset( $content_width ) ) $content_width = 1020;
    }


    /**
     * Add actions and filters in wordpress theme. All the actions will be here.
     * 
     * @uses add_action()
     * @uses add_filter()
     * @since v1.0
     */
    public function add_actions() {

        add_action( 'template_redirect', array($this, 'coming_soon_page') );

        // Register all wp scripts and styles
        add_action( 'wp_enqueue_scripts', array($this, 'load_wp_scripts_and_styles') );

        // Register custom fonts used in the theme.
        add_action('wp_print_styles', array( $this, 'load_fonts' ));

        // Post title filter.
        add_filter( "wp_title", array( $this, "page_title" ) );

        // Change excerpt lenght
        add_filter( 'excerpt_length', array( $this, 'excerpt_length' ), 10 );

        // Add read more link instead of [...]
        add_filter( 'excerpt_more', array( $this, 'excerpt_more' ) );

    }

    public function coming_soon_page() {
        $coming_soon = livekitchen_theme_get_customizer_field('coming_soon_page','coming_soon');
        if ($coming_soon == "1") {
            $curent_page_id = get_the_ID();
            $page_id = livekitchen_theme_get_customizer_field('coming_soon_page','1','coming_soon_page_id', '0');
            $page_url = get_page_link($page_id);

            if ( $curent_page_id != $page_id) {
                wp_redirect( $page_url ); exit;
            }
        }
    }

    /**
     * Loading scripts and stylesheets for Innocence
     * The order of initialising bootstrap css files is important
     * for the theme responsivness work proerly.
     * 
     * @uses wp_enqueue_style()
     * @since v1.0
     */
    public function load_wp_scripts_and_styles() {
        require get_template_directory() . '/inc/classes/frontend/partials/action_wp_enqueue_scripts.php';
    }


    /**
     * Register fonts used in the theme. It is better to include them
     * from this file instead from hardcoding in header.php
     * 
     * @since  v1.0
     */
    public function load_fonts() {
        // wp_register_style('googleFonts', 'http://fonts.googleapis.com/css?family=Source+Sans+Pro:400,700');
        // wp_enqueue_style( 'googleFonts');
    }

    /*
    Register Google Fonts
    */
    public function google_fonts_url() {
        $font_url = '';
        
        /*
        Translators: If there are characters in your language that are not supported
        by chosen font(s), translate this to 'off'. Do not translate into your own language.
         */
        if ( 'off' !== esc_html_x( 'on', 'Google font: on or off', 'livekitchen' ) ) {
            $font_url = add_query_arg( 'family', urlencode( 'Poppins:300,400,500,600,700%7cPlayfair+Display:400,700,900' ), "https://fonts.googleapis.com/css" );
        }
        return $font_url;
    }


    /**
     * Write the theme title. It doesnt return anything.
     * The simple name comes, because its very natural when call it:
     * Header::title();
     * 
     * @uses get_bloginfo()
     * @uses wp_title()
     * @uses is_home()
     * @uses is_front_page();
     * 
     * @since  v1.0
     */
    public function page_title( $title, $sep = ' | ' ) {
        global $page, $paged;

        if ( is_feed() )
            return $title;

        $site_description = get_bloginfo( 'description' );

        $filtered_title = $title . get_bloginfo( 'name' );
        $filtered_title .= ( ! empty( $site_description ) && ( is_home() || is_front_page() ) ) ? $sep . $site_description: '';
        $filtered_title .= ( 2 <= $paged || 2 <= $page ) ? $sep . sprintf( __( 'Page %s', 'livekitchen' ), max( $paged, $page ) ) : '';

        return $filtered_title;
    }

    /**
     * Change the default valued for length of the post excerpt.
     * @param  int $length The length of desired excerpt. (for all pages and all calls)
     * @return int         Hardcoded value of the excerpt length
     */
    public function excerpt_length( $length ) {
        return $length;
    }

    /**
     * Change the default valued for after the post excerpt.
     * @param  string $more Not used vcariable, wanted from WP
     * @return string       Link for the post.
     */
    public function excerpt_more( $more ) {
        return ' <a class="read-more" href="'. get_permalink( get_the_ID() ) . '">Read More</a>';
    }

    /**
     * Add custom style for the header. 
     * It look quite hard to read, but the main logic is to setup
     * custom styling when there is custom header image set.
     * 
     * @return void
     * @since v1.0
     */
    function custom_header_css() {
        $header_image = get_header_image();

        // This will be printed as stylesheet in the header.
        $output = '<style type="text/css">';

        // Here you can write the custom CSS that will be set after the theme has
        // changed the settings from the theme Customizer. Write the classes and
        // ID's that will be affected from that change.
        $output .= ".site-title a,";
        $output .= ".site-description {";

        // Check if the site title text should be displayed.
        if( get_header_textcolor() == 'blank' ) {
            $output .= 'visibility: hidden;'; 
        }
        else {
            $output .= 'color: #' . get_header_textcolor() . ' !important';
        }

        // Close the title and desc styles.
        $output .= "}";

        // Close the style tag
        $output .= '</style>';

        // Print the final styles.
        echo livekitchen_content_print( $output );
    }
}

// Removing this line is like not having a functions.php file
new Livekitchen_Theme_Master;

endif;